JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
metaform: only require_once(email.php) if needed
[wfpl.git] / run.php
diff --git a/run.php b/run.php
index 1561446..8cf9d4d 100644 (file)
--- a/run.php
+++ b/run.php
 # RewriteRule    ^$  /foo/run.php
 # RewriteRule    ^foo/[^/]*\.html$  /foo/run.php
 
-require_once('code/wfpl/file_run.php');
-require_once('code/wfpl/http.php');
-require_once('code/wfpl/template.php');
+require_once(__DIR__.'/'.'code/wfpl/file_run.php');
+require_once(__DIR__.'/'.'code/wfpl/http.php');
+require_once(__DIR__.'/'.'code/wfpl/template.php');
 
-if(file_exists('code/config.php')) {
-       file_run('code/config.php');
+if(file_exists(__DIR__.'/'.'code/config.php')) {
+       file_run(__DIR__.'/'.'code/config.php');
 }
 
 # pass the basename of the page you want for normal execution
@@ -72,7 +72,7 @@ function run_php($dest = false) {
        } else { # no dest arg
                $basename = $_SERVER['REDIRECT_URL'];
                $basename = ereg_replace('.*/', '', $basename);
-               $basename = ereg_replace('\.html$', '', $basename);
+               $basename = ereg_replace('\.html?$', '', $basename);
                if($basename == '') {
                        $basename = 'index';
                }
@@ -90,9 +90,6 @@ function run_php($dest = false) {
                $GLOBALS['wfpl_main_template'] = new tem();
                $GLOBALS['wfpl_main_template']->load("template.html");
                $GLOBALS['wfpl_main_template']->set('$basename', $basename);
-               if(preg_match('/([.]l(ocal)?$)|^[0-9.]*$/', $_SERVER['HTTP_HOST'])) {
-                       $GLOBALS['wfpl_main_template']->set('$running_locally');
-               }
        }
 
        # cms_get can return one of:
@@ -159,8 +156,8 @@ function run_php($dest = false) {
                }
 
 
# You'll probably want to require_once('code/wfpl/messages.php') or
# require_once('code/wfpl/session_messages.php') in code/config.php
                if(function_exists('display_messages')) {
                        if(function_exists('atexit_now')) {
                                atexit_now();
@@ -159,8 +156,8 @@ function run_php($dest = false) {
 
 
-               # You'll probably want to require_once('code/wfpl/messages.php') or
-               # require_once('code/wfpl/session_messages.php') in code/config.php
+               # You'll probably want to require_once(__DIR__.'/'.'code/wfpl/messages.php') or
+               # require_once(__DIR__.'/'.'code/wfpl/session_messages.php') in code/config.php
                if(function_exists('display_messages')) {
                        if(function_exists('atexit_now')) {